pub struct SendPlan { /* private fields */ }Expand description
A compiled send plan that can be inspected locally without transmitting.
Implementations
Sourceimpl SendPlan
impl SendPlan
Sourcepub fn from_packet(
packet: &Packet,
options: impl Into<SendOptions>,
) -> Result<Self>
pub fn from_packet( packet: &Packet, options: impl Into<SendOptions>, ) -> Result<Self>
Build a send plan by compiling a packet and resolving the requested send target.
Sourcepub const fn requested_mode(&self) -> SendMode
pub const fn requested_mode(&self) -> SendMode
Requested send mode.
Sourcepub const fn target(&self) -> SendTarget
pub const fn target(&self) -> SendTarget
Resolved send target.
Sourcepub const fn compiled_packet(&self) -> &CompiledPacket
pub const fn compiled_packet(&self) -> &CompiledPacket
Borrow the compiled packet.