Packet

Struct Packet 

pub struct Packet { /* private fields */ }
Ordered stack of packet layers.

Implementations

Source

impl Packet

pub const fn new() -> Self

Create an empty packet.

pub fn from_layer<L>(layer: L) -> Self
where L: Layer,

Create a packet containing one layer.

pub fn push<L>(self, layer: L) -> Self
where L: Layer,

Append a concrete layer and return the packet for builder chaining.

pub fn push_box(self, layer: Box<dyn Layer>) -> Self

Append a boxed layer and return the packet for builder chaining.

pub fn push_mut<L>(&mut self, layer: L) -> &mut Self
where L: Layer,

Mutably append a concrete layer.

pub fn push_box_mut(&mut self, layer: Box<dyn Layer>) -> &mut Self

Mutably append a boxed layer.

pub fn concat(self, other: impl IntoPacket) -> Self

Append all layers from another packet.

pub fn extend(&mut self, other: impl IntoPacket) -> &mut Self

Mutably append all layers from another packet.

pub fn pop(&mut self) -> Option<Box<dyn Layer>>

Remove and return the final layer.

pub fn pop_typed<T>(&mut self) -> Option<T>
where T: Layer,

Remove and return the final layer when it has type T.

pub fn len(&self) -> usize

Number of layers in the packet.

pub fn is_empty(&self) -> bool

Return true when the packet contains no layers.

pub fn encoded_len(&self) -> usize

Return the encoded byte length implied by the current layers.

pub fn get(&self, index: usize) -> Option<&dyn Layer>

Positional layer access.

pub fn get_mut(&mut self, index: usize) -> Option<&mut dyn Layer>

Mutable positional layer access.

pub fn layer<T>(&self) -> Option<&T>
where T: Layer,

First layer of type T.

pub fn layer_mut<T>(&mut self) -> Option<&mut T>
where T: Layer,

First mutable layer of type T.

pub fn layers<T>(&self) -> impl Iterator<Item = &T>
where T: Layer,

All layers of type T, preserving packet order.

pub fn layers_mut<T>(&mut self) -> impl Iterator<Item = &mut T>
where T: Layer,

All mutable layers of type T, preserving packet order.

pub fn iter(&self) -> impl Iterator<Item = &dyn Layer>

Ordered layer iteration.

pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut dyn Layer>

Ordered mutable layer iteration.

pub fn compile(&self) -> Result<CompiledPacket>

Compile the packet into deterministic bytes.

pub fn compile_into(&self, out: &mut Vec<u8>) -> Result<()>

Append compiled bytes into an existing buffer.

pub fn decode_raw(bytes: impl AsRef<[u8]>) -> Result<Self>

Decode bytes as raw payload.

Decode bytes from a link-layer entrypoint.

Decode bytes from a link-layer entrypoint using an explicit registry.

pub fn decode_from_l3( network_layer: NetworkLayer, bytes: impl AsRef<[u8]>, ) -> Result<Self>

Decode bytes from a network-layer entrypoint.

pub fn decode_from_l3_with_registry( registry: &ProtocolRegistry, network_layer: NetworkLayer, bytes: impl AsRef<[u8]>, ) -> Result<Self>

Decode bytes from a network-layer entrypoint using an explicit registry.

pub fn summary(&self) -> String

One-line packet summary.

pub fn show(&self) -> String

Multi-line packet tree intended for display in examples and tools.

pub fn hexdump(&self) -> Result<String>

Compile and return a canonical hex dump.

pub fn raw_string_lossy(&self) -> Result<String>

Compile and return raw bytes as a lossy UTF-8 string.