Ipv6MobileRoutingHeader

Struct Ipv6MobileRoutingHeader 

pub struct Ipv6MobileRoutingHeader { /* private fields */ }
IPv6 Mobile Routing Header (Routing Header type 2).

Implementations

Source

impl Ipv6MobileRoutingHeader

pub fn new() -> Self

Create a mobile routing header.

pub fn next_header(self, next_header: u8) -> Self

Set the next header after this routing header.

pub fn nh(self, next_header: u8) -> Self

Compatibility alias for next header.

pub fn header_ext_len(self, header_ext_len: u8) -> Self

Set the encoded header extension length.

pub fn routing_type(self, routing_type: u8) -> Self

Set the routing type field.

pub fn segments_left(self, segments_left: u8) -> Self

Set the segments-left field.

pub fn segleft(self, segments_left: u8) -> Self

libcrafter-style alias for segments left.

pub fn reserved(self, reserved: u32) -> Self

Set the reserved field.

pub fn home_address(self, home_address: Ipv6Addr) -> Self

Set the home address.

pub fn home(self, home_address: Ipv6Addr) -> Self

libcrafter-style alias for home address.

pub fn home_address_str(self, home_address: &str) -> Result<Self>

Set the home address from text.

pub fn home_str(self, home_address: &str) -> Result<Self>

libcrafter-style alias for textual home address.

pub fn next_header_value(&self) -> u8

Next-header value.

pub fn header_ext_len_value(&self) -> Option<u8>

Header extension length when explicit or decoded.

pub fn effective_header_ext_len_value(&self) -> u8

Header extension length that will be emitted if the header compiles.

pub fn header_ext_len_status(&self) -> Ipv6MobileRoutingHeaderStatus

RFC 6275 status of the header extension length field.

pub fn routing_type_value(&self) -> u8

Routing type.

pub fn routing_type_label(&self) -> &'static str

Routing type label from the IANA IPv6 Routing Types registry.

pub fn routing_type_status(&self) -> Ipv6RoutingTypeStatus

Routing type status from the IANA IPv6 Routing Types registry.

pub fn segments_left_value(&self) -> u8

Segments-left value.

pub fn segments_left_is_defaulted(&self) -> bool

Whether Segments Left is still using the RFC 6275 builder default.

pub fn segments_left_status(&self) -> Ipv6MobileRoutingHeaderStatus

RFC 6275 status of the Segments Left field.

pub fn reserved_value(&self) -> u32

Reserved field.

pub fn reserved_is_zero(&self) -> bool

Whether the reserved field is zero as initialized by RFC 6275 senders.

pub fn reserved_status(&self) -> Ipv6MobileRoutingHeaderStatus

RFC 6275 status of the reserved field.

pub fn home_address_value(&self) -> Ipv6Addr

Home address value.

pub fn home_address_bytes(&self) -> [u8; 16]

Home address field bytes in network order.

pub fn validity_status(&self) -> Ipv6MobileRoutingHeaderStatus

RFC 6275 packet-field status for this Type 2 Routing Header.