QuicHeader

Struct QuicHeader 

pub struct QuicHeader { /* private fields */ }
Raw-preserving QUIC header placeholder.

Implementations

Source

impl QuicHeader

pub fn new() -> Self

Create an empty placeholder header.

pub fn from_decoded_bytes(bytes: impl AsRef<[u8]>) -> Result<Self>

Preserve raw header bytes recovered from the wire.

pub fn first_byte(self, first_byte: u8) -> Self

Pin the first header byte explicitly.

pub fn header_form(self, form: QuicHeaderForm) -> Self

Set the invariant header form bit while preserving every other bit.

pub fn fixed_bit(self, fixed: bool) -> Self

Set the QUIC fixed bit while preserving every other bit.

pub fn grease_quic_bit(self) -> Self

Clear the QUIC bit explicitly for RFC 9287 greasing.

pub fn long_packet_type_bits(self, bits: u8) -> Self

Set the v1/v2 long-header packet type bits while preserving other bits.

pub fn long_reserved_bits(self, bits: u8) -> Self

Set the v1/v2 long-header reserved bits while preserving other bits.

pub fn short_spin_bit(self, spin: bool) -> Self

Set the short-header spin bit while preserving every other bit.

pub fn short_reserved_bits(self, bits: u8) -> Self

Set the v1/v2 short-header reserved bits while preserving other bits.

pub fn short_key_phase(self, key_phase: bool) -> Self

Set the short-header key-phase bit while preserving every other bit.

pub fn packet_number_len_bits(self, bits: u8) -> Self

Set raw packet-number length bits while preserving every other bit.

pub fn packet_number_len(self, encoded_len: usize) -> Result<Self>

Set packet-number length bits from a 1, 2, 3, or 4-byte length.

pub fn first_byte_value(&self) -> Option<u8>

Stored first-byte value, if one has been supplied or decoded.

pub fn first_byte_state(&self) -> FieldState

State of the first-byte field.

pub fn header_form_value(&self) -> Option<QuicHeaderForm>

Invariant header form, if byte 0 is present.

pub fn is_long_header(&self) -> Option<bool>

Return true when byte 0 identifies a long header.

pub fn is_short_header(&self) -> Option<bool>

Return true when byte 0 identifies a short header.

pub fn fixed_bit_value(&self) -> Option<bool>

QUIC/fixed bit value, if byte 0 is present.

pub fn quic_bit_status_value(&self) -> Option<QuicFixedBitStatus>

RFC 9287 QUIC bit status, if byte 0 is present.

pub fn quic_bit_label_value(&self) -> Option<&'static str>

RFC 9287 QUIC bit label, if byte 0 is present.

pub fn long_packet_type_bits_value(&self) -> Option<u8>

Raw v1/v2 long-header packet type bits, if byte 0 is present.

pub fn long_reserved_bits_value(&self) -> Option<u8>

Raw v1/v2 long-header reserved bits, if byte 0 is present.

pub fn short_spin_bit_value(&self) -> Option<bool>

Short-header spin bit value, if byte 0 is present.

pub fn short_reserved_bits_value(&self) -> Option<u8>

Raw v1/v2 short-header reserved bits, if byte 0 is present.

pub fn short_key_phase_value(&self) -> Option<bool>

Short-header key-phase bit value, if byte 0 is present.

pub fn packet_number_len_bits_value(&self) -> Option<u8>

Raw packet-number length bits, if byte 0 is present.

pub fn packet_number_len_value(&self) -> Option<usize>

Decoded packet-number length in bytes, if byte 0 is present.

pub fn destination_connection_id_field_present(&self) -> Option<bool>

Return whether this header form carries a Destination Connection ID field.

Long headers encode the field length after the version. Short headers carry the field immediately after byte 0, but the length is contextual.

pub fn raw_bytes(&self) -> &[u8]

Borrow the preserved raw header bytes.