pub struct Ipv6MobileRoutingHeader { /* private fields */ }Expand description
IPv6 Mobile Routing Header (Routing Header type 2).
Implementations
Sourceimpl Ipv6MobileRoutingHeader
impl Ipv6MobileRoutingHeader
Sourcepub fn next_header(self, next_header: u8) -> Self
pub fn next_header(self, next_header: u8) -> Self
Set the next header after this routing header.
Sourcepub fn header_ext_len(self, header_ext_len: u8) -> Self
pub fn header_ext_len(self, header_ext_len: u8) -> Self
Set the encoded header extension length.
Sourcepub fn routing_type(self, routing_type: u8) -> Self
pub fn routing_type(self, routing_type: u8) -> Self
Set the routing type field.
Sourcepub fn segments_left(self, segments_left: u8) -> Self
pub fn segments_left(self, segments_left: u8) -> Self
Set the segments-left field.
Sourcepub fn home_address(self, home_address: Ipv6Addr) -> Self
pub fn home_address(self, home_address: Ipv6Addr) -> Self
Set the home address.
Sourcepub fn home_address_str(self, home_address: &str) -> Result<Self>
pub fn home_address_str(self, home_address: &str) -> Result<Self>
Set the home address from text.
Sourcepub fn home_str(self, home_address: &str) -> Result<Self>
pub fn home_str(self, home_address: &str) -> Result<Self>
libcrafter-style alias for textual home address.
Sourcepub fn next_header_value(&self) -> u8
pub fn next_header_value(&self) -> u8
Next-header value.
Sourcepub fn header_ext_len_value(&self) -> Option<u8>
pub fn header_ext_len_value(&self) -> Option<u8>
Header extension length when explicit or decoded.
Sourcepub fn effective_header_ext_len_value(&self) -> u8
pub fn effective_header_ext_len_value(&self) -> u8
Header extension length that will be emitted if the header compiles.
Sourcepub fn header_ext_len_status(&self) -> Ipv6MobileRoutingHeaderStatus
pub fn header_ext_len_status(&self) -> Ipv6MobileRoutingHeaderStatus
RFC 6275 status of the header extension length field.
Sourcepub fn routing_type_value(&self) -> u8
pub fn routing_type_value(&self) -> u8
Routing type.
Sourcepub fn routing_type_label(&self) -> &'static str
pub fn routing_type_label(&self) -> &'static str
Routing type label from the IANA IPv6 Routing Types registry.
Sourcepub fn routing_type_status(&self) -> Ipv6RoutingTypeStatus
pub fn routing_type_status(&self) -> Ipv6RoutingTypeStatus
Routing type status from the IANA IPv6 Routing Types registry.
Sourcepub fn segments_left_value(&self) -> u8
pub fn segments_left_value(&self) -> u8
Segments-left value.
Sourcepub fn segments_left_is_defaulted(&self) -> bool
pub fn segments_left_is_defaulted(&self) -> bool
Whether Segments Left is still using the RFC 6275 builder default.
Sourcepub fn segments_left_status(&self) -> Ipv6MobileRoutingHeaderStatus
pub fn segments_left_status(&self) -> Ipv6MobileRoutingHeaderStatus
RFC 6275 status of the Segments Left field.
Sourcepub fn reserved_value(&self) -> u32
pub fn reserved_value(&self) -> u32
Reserved field.
Sourcepub fn reserved_is_zero(&self) -> bool
pub fn reserved_is_zero(&self) -> bool
Whether the reserved field is zero as initialized by RFC 6275 senders.
Sourcepub fn reserved_status(&self) -> Ipv6MobileRoutingHeaderStatus
pub fn reserved_status(&self) -> Ipv6MobileRoutingHeaderStatus
RFC 6275 status of the reserved field.
Sourcepub fn home_address_value(&self) -> Ipv6Addr
pub fn home_address_value(&self) -> Ipv6Addr
Home address value.
Sourcepub fn home_address_bytes(&self) -> [u8; 16]
pub fn home_address_bytes(&self) -> [u8; 16]
Home address field bytes in network order.
Sourcepub fn validity_status(&self) -> Ipv6MobileRoutingHeaderStatus
pub fn validity_status(&self) -> Ipv6MobileRoutingHeaderStatus
RFC 6275 packet-field status for this Type 2 Routing Header.